@@ -7,8 +7,6 @@ import sys
 
 number = sys.argv[1]
 message = sys.argv[2]
-print "Number:" + number
-print "Message:" + message
 
 child = pexpect.spawn('pnatd');
 child.send('at\r');
